@@ -220,20 +220,20 @@ update_weak_contact (EmpathyIndividualWidget *self)
       personas = folks_individual_get_personas (priv->individual);
       for (l = personas; l != NULL; l = l->next)
         {
-          FolksHasPresence *presence;
+          FolksPresenceOwner *presence;
 
           /* We only want personas which implement FolksPresence */
-          if (!FOLKS_IS_HAS_PRESENCE (l->data))
+          if (!FOLKS_IS_PRESENCE_OWNER (l->data))
             continue;
 
-          presence = FOLKS_HAS_PRESENCE (l->data);
+          presence = FOLKS_PRESENCE_OWNER (l->data);
 
-          if (folks_has_presence_typecmp (
-                  folks_has_presence_get_presence_type (presence),
+          if (folks_presence_owner_typecmp (
+                  folks_presence_owner_get_presence_type (presence),
                   presence_type) > 0
               && TPF_IS_PERSONA (presence))
             {
-              presence_type = folks_has_presence_get_presence_type (presence);
+              presence_type = folks_presence_owner_get_presence_type (presence);
               tp_contact = tpf_persona_get_contact (TPF_PERSONA (l->data));
             }
         }
@@ -1248,13 +1248,13 @@ notify_presence_cb (gpointer folks_object,
   state_image = g_object_get_data (table, "state-image");
 
   /* FIXME: Default messages should be moved into libfolks (bgo#627403) */
-  message = folks_has_presence_get_presence_message (
-      FOLKS_HAS_PRESENCE (folks_object));
+  message = folks_presence_owner_get_presence_message (
+      FOLKS_PRESENCE_OWNER (folks_object));
   if (EMP_STR_EMPTY (message))
     {
       message = empathy_presence_get_default_message (
-          folks_has_presence_get_presence_type (
-              FOLKS_HAS_PRESENCE (folks_object)));
+          folks_presence_owner_get_presence_type (
+              FOLKS_PRESENCE_OWNER (folks_object)));
     }
 
   if (message != NULL)
@@ -1264,8 +1264,8 @@ notify_presence_cb (gpointer folks_object,
 
   gtk_image_set_from_icon_name (GTK_IMAGE (state_image),
       empathy_icon_name_for_presence (
-          folks_has_presence_get_presence_type (
-              FOLKS_HAS_PRESENCE (folks_object))),
+          folks_presence_owner_get_presence_type (
+              FOLKS_PRESENCE_OWNER (folks_object))),
       GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (state_image);
 }
