@@ -105,6 +105,9 @@ void           empathy_tp_chat_join                 (EmpathyTpChat      *chat);
 
 gboolean       empathy_tp_chat_is_invited           (EmpathyTpChat      *chat,
 						     TpHandle *inviter);
+TpChannelChatState
+               empathy_tp_chat_get_chat_state       (EmpathyTpChat      *chat,
+               	             EmpathyContact *contact);
 
 G_END_DECLS
 
